@@ -12,6 +12,7 @@ exceptions
 - ProcessTypeMustBeOfClassProcessType
 - ProcessTypeNotRegistered
 """
+from typing import List
 
 
 class FieldNameMandatory(Exception):
@@ -149,3 +150,18 @@ class InvalidSubProcessForProcessType(Exception):
     def __init__(self):
         message = "Provided sub process is not defined in ProcessType."
         super().__init__(message)
+
+
+class InvalidTelemetryType(Exception):
+    def __init__(self, available_types: List[str]):
+        message = \
+            f"Telemetry Type must be of type: {', '.join(available_types)}."
+        super().__init__(message)
+
+
+class ClassTelemetryParamsNotDefined(Exception):
+    def __init__(self, object):
+        class_name = object.__class__.__name__
+        message = \
+            f"Telemetry params not defined for class {class_name}"
+        super().__init__(message)
