@@ -1,6 +1,7 @@
 """Module to test storage module.
 """
 import sqlite3
+from datetime import datetime
 
 from freezegun import freeze_time
 
@@ -57,7 +58,7 @@ def test_store_telemetry_stores_object():
 @freeze_time("2022-01-18 18:00:00.123456")
 def test_store_telemetry_stores_object_with_create_date(mocker):
     """Test in memory storage instance has db_in_memory and db_cursor"""
-    telemetry = {"source_name": "test"}
+    telemetry = {"source_name": "test", "start_date_time": datetime.now()}
     # Table reset for each test is needed as the table is a class property
     TelemetryInMemoryStorage._define_db_table(TelemetryInMemoryStorage.db_cursor)
     in_memory_storage = TelemetryInMemoryStorage()
@@ -65,7 +66,8 @@ def test_store_telemetry_stores_object_with_create_date(mocker):
     in_memory_record = in_memory_storage.db_cursor.execute(
         "SELECT * FROM telemetry LIMIT 1"
     ).fetchone()
-    assert in_memory_record[7] == "2022-01-18 18:00:00.123456"
+    print(in_memory_record)
+    assert in_memory_record[5] == "2022-01-18 18:00:00.123456"
 
 
 def test_telemetry_mongo_model_class_exists():
@@ -104,12 +106,14 @@ def test_telemetry_model_kwargs_method():
     """Test _telemetry_model_kwargs method returns correct kwargs."""
     result = TelemetryMongoStorage()._telemetry_model_kwargs(
         {
+            "telemetry_type": "test telemetry type",
             "category": "test",
             "sub_category": "sub_test",
             "source_name": "tst_source_name",
             "process_type": "tst_process_type",
             "start_date_time": "tst_start_date_time",
             "run_time_in_seconds": "tst_run_time_in_seconds",
+            "io_time_in_seconds": 1.1,
             "field1": {"a": 1},
             "field2": "value",
             "traffic_light": DEFAULT_TRAFIC_LIGHT_COLOR,
@@ -117,12 +121,14 @@ def test_telemetry_model_kwargs_method():
     )
 
     assert result == {
+        "telemetry_type": "test telemetry type",
         "category": "test",
         "sub_category": "sub_test",
         "source_name": "tst_source_name",
         "process_type": "tst_process_type",
         "start_date_time": "tst_start_date_time",
         "run_time_in_seconds": "tst_run_time_in_seconds",
+        "io_time_in_seconds": 1.1,
         "telemetry": {"field1": {"a": 1}, "field2": "value"},
         "traffic_light": DEFAULT_TRAFIC_LIGHT_COLOR,
     }
